==> jc-1.4.0.tar.gz: soot/jimple/spark/internal/TypeManager.h <==
// public final class soot.jimple.spark.internal.TypeManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager
// @dep_class a80e955b23109b62 soot_jimple_spark_internal_TypeManager

// header file dependencies
// @dep_header soot_jimple_spark_internal_AbstractTypeManager

#include "soot/jimple/spark/internal/AbstractTypeManager.h"

#ifndef _JC_soot_jimple_spark_internal_TypeManager_H_
#define _JC_soot_jimple_spark_internal_TypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_util_BitVector$object;
struct _jc_soot_util_LargeNumberedMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_TypeManager$sub_refs	_jc_soot_jimple_spark_internal_TypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$refs	_jc_soot_jimple_spark_internal_TypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$nonrefs	_jc_soot_jimple_spark_internal_TypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$object	_jc_soot_jimple_spark_internal_TypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vmethods	_jc_soot_jimple_spark_internal_TypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vtable	_jc_soot_jimple_spark_internal_TypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vtype	_jc_soot_jimple_spark_internal_TypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_TypeManager$method$_init$47a8894d06f422db(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_internal_TypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *);
extern struct _jc_soot_util_BitVector$object *_jc_soot_jimple_spark_internal_TypeManager$method$get$0d267f0685f40848(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_Type$object *);
extern void _jc_soot_jimple_spark_internal_TypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$get$0d267f0685f40848;
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$makeTypeMask$f36568e0574d6282;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_TypeManager$vmethods {
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *);
	struct _jc_soot_util_BitVector$object	*(*get$0d267f0685f40848)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_Type$object *);
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *);
};

// Vtable
struct _jc_soot_jimple_spark_internal_TypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
	_jc_soot_jimple_spark_internal_TypeManager$vmethods	soot_jimple_spark_internal_TypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_TypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_TypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_TypeManager$sub_refs {
	struct _jc_soot_util_LargeNumberedMap$object	*typeMask;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_TypeManager$refs {
    _jc_soot_jimple_spark_internal_TypeManager$sub_refs	soot_jimple_spark_internal_TypeManager;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_TypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs	soot_jimple_spark_internal_TypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_TypeManager$object {
	_jc_soot_jimple_spark_internal_TypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_TypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_TypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_TypeManager$vtype _jc_soot_jimple_spark_internal_TypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_TypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_TypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_TypeManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/internal/TypeManager.h <==
// public final class soot.jimple.spark.internal.TypeManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager
// @dep_class a80e955b23109b62 soot_jimple_spark_internal_TypeManager

// header file dependencies
// @dep_header soot_jimple_spark_internal_AbstractTypeManager

#include "soot/jimple/spark/internal/AbstractTypeManager.h"

#ifndef _JC_soot_jimple_spark_internal_TypeManager_H_
#define _JC_soot_jimple_spark_internal_TypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_util_BitVector$object;
struct _jc_soot_util_LargeNumberedMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_TypeManager$sub_refs	_jc_soot_jimple_spark_internal_TypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$refs	_jc_soot_jimple_spark_internal_TypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$nonrefs	_jc_soot_jimple_spark_internal_TypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_TypeManager$object	_jc_soot_jimple_spark_internal_TypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vmethods	_jc_soot_jimple_spark_internal_TypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vtable	_jc_soot_jimple_spark_internal_TypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_TypeManager$vtype	_jc_soot_jimple_spark_internal_TypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_TypeManager$method$_init$47a8894d06f422db(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_internal_TypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_BitVector$object *_jc_soot_jimple_spark_internal_TypeManager$method$get$0d267f0685f40848(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_TypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$get$0d267f0685f40848;
extern _jc_method _jc_soot_jimple_spark_internal_TypeManager$method_info$makeTypeMask$f36568e0574d6282;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_TypeManager$vmethods {
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_BitVector$object	*(*get$0d267f0685f40848)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_TypeManager$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_internal_TypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
	_jc_soot_jimple_spark_internal_TypeManager$vmethods	soot_jimple_spark_internal_TypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_TypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_TypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_TypeManager$sub_refs {
	struct _jc_soot_util_LargeNumberedMap$object	*typeMask;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_TypeManager$refs {
    _jc_soot_jimple_spark_internal_TypeManager$sub_refs	soot_jimple_spark_internal_TypeManager;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_TypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_soot_jimple_spark_internal_TypeManager$sub_nonrefs	soot_jimple_spark_internal_TypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_TypeManager$object {
	_jc_soot_jimple_spark_internal_TypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_TypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_TypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_TypeManager$vtype _jc_soot_jimple_spark_internal_TypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_TypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_TypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_TypeManager_H_ */
